#!/bin/sh
set -e
STARTDIR=$(pwd)
cd ../../Source
make -f macosx.mak clean all
cd $STARTDIR

${PYTHON} make_pkg.py
